unpolish-ai-writing
Agent skill that removes signs of AI-generated writing, and optionally adds sparse typing errors using probability distributions informed by researched human…
Find an Agent Skill for your task. Read the guide and copy the install command.
Updated 11-05 00:16
245,575 results
Agent skill that removes signs of AI-generated writing, and optionally adds sparse typing errors using probability distributions informed by researched human…
Explain how code works in detail. Use when trying to understand unfamiliar code, complex logic, or system architecture.
Write a numbered plan with an acceptance check for each step, critique it once in a fresh pass, revise it, then execute one step at a time. Use when a task…
Score and tier a list of accounts (or your full book) against ICP fit and engagement signals to prioritize where to spend time. Use when the user asks to "tier…
Keeps the CRM current without the owner ever opening it. Creates and updates contacts and deals from email, calendar, and call transcripts; logs activity…
Delivers the owner's custom recurring report pack on a set cadence — runs the saved report definition from report-builder, wraps it in a business-pulse…
Audit and safely clean Xcode-related developer storage on macOS. Use whenever a developer mentions low disk space, Xcode storage, DerivedData, simulator…
Hunting skill for race condition vulnerabilities. Built from 12 public bug bounty reports including modern HTTP/2 single-packet attack cases (James Kettle DEF…
Investigation: Before making a judgment, decision, or recommendation, first use first-hand material to clarify the current situation, and produce an investigation conclusion in three columns: "facts / inferences / unknowns." Trigger when the context is incomplete, the evidence is weak, the domain is unfamiliar, the user says "don't act yet," or you notice you are answering from impressions; do not trigger it repeatedly during the execution phase after investigation has already been sufficient. English: Investigate before judging.…
Load first. State-today index of distilled Eve Horizon system docs with task-based routing for CLI/API usage, manifests, pipelines, jobs, secrets, agents,…
Use when you need programmatic JDBC in Micronaut — pooled DataSource, parameterized SQL, io.micronaut.transaction.annotation.Transactional, batching, and…
Video understanding and transcription with intelligent multi-provider fallback. Use when: (1) Transcribing video or audio content, (2) Understanding video…
Project orchestrator for the screenwriting skill set (screenplay project mainline scheduling / state archiving / story bible) — a meta-skill that adds no new craft knowledge but routes a screenplay or…
Comprehensive guide for this Neovim configuration - a modular, performance-optimized Lua-based IDE. Use when configuring plugins, adding keybindings, setting…
Triton language skill for Python GPU kernel authoring. Use when writing Triton kernels with @triton.jit, tl.load/store, masking, atomics, benchmarking with…
Fetch and analyze Linear issue with all related context. Use when starting work on a Linear ticket, analyzing issues, or gathering context about a Linear issue.
Add new skills to an existing workflow and update all related documentation. Use when user wants to add skills from GitHub URLs to a workflow (e.g., "add this…
Use the Nylas CLI to manage email, calendar, contacts, and Notetaker from the terminal. Use when user asks about Nylas CLI commands, nylas init, nylas email,…
Crafting examples that steer AI behavior effectively.
Expert-level Java development with Java 21+ features, Spring Boot, Maven/Gradle, and enterprise best practices. Use when the user mentions JVM, Spring, Maven,…
Gate every generation through a brand policy file.
Core gameplay mechanics implementation, system interactions, feedback loops, and iterative balance refinement for engaging player experiences.
Set up or update the agent-first engineering harness for any repository. Implements the complete scaffolding that makes AI coding agents effective: knowledge…
Report a finished task as its result, not its transcript. Or tell the user what happened since their last message. Read this skill before your final report on…